# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
StepAP203 module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_stepap203.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _StepAP203
else:
    import _StepAP203

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _StepAP203.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _StepAP203.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepAP203.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _StepAP203.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _StepAP203.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _StepAP203.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _StepAP203.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _StepAP203.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _StepAP203.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _StepAP203.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepAP203.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _StepAP203.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _StepAP203.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepAP203.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _StepAP203.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _StepAP203.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _StepAP203.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _StepAP203:
_StepAP203.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _StepAP203.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.StepData
import OCC.Core.Interface
import OCC.Core.TCollection
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.TColStd
import OCC.Core.MoniTool
import OCC.Core.TopoDS
import OCC.Core.TopAbs
import OCC.Core.TopLoc
import OCC.Core.gp
import OCC.Core.Resource
import OCC.Core.StepBasic
import OCC.Core.StepRepr

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_StepAP203_CcDesignApproval_Create() -> "opencascade::handle< StepAP203_CcDesignApproval >":
    return _StepAP203.Handle_StepAP203_CcDesignApproval_Create()

def Handle_StepAP203_CcDesignApproval_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignApproval >":
    return _StepAP203.Handle_StepAP203_CcDesignApproval_DownCast(t)

def Handle_StepAP203_CcDesignApproval_IsNull(t: "opencascade::handle< StepAP203_CcDesignApproval > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignApproval_IsNull(t)

def Handle_StepAP203_CcDesignCertification_Create() -> "opencascade::handle< StepAP203_CcDesignCertification >":
    return _StepAP203.Handle_StepAP203_CcDesignCertification_Create()

def Handle_StepAP203_CcDesignCertification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignCertification >":
    return _StepAP203.Handle_StepAP203_CcDesignCertification_DownCast(t)

def Handle_StepAP203_CcDesignCertification_IsNull(t: "opencascade::handle< StepAP203_CcDesignCertification > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignCertification_IsNull(t)

def Handle_StepAP203_CcDesignContract_Create() -> "opencascade::handle< StepAP203_CcDesignContract >":
    return _StepAP203.Handle_StepAP203_CcDesignContract_Create()

def Handle_StepAP203_CcDesignContract_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignContract >":
    return _StepAP203.Handle_StepAP203_CcDesignContract_DownCast(t)

def Handle_StepAP203_CcDesignContract_IsNull(t: "opencascade::handle< StepAP203_CcDesignContract > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignContract_IsNull(t)

def Handle_StepAP203_CcDesignDateAndTimeAssignment_Create() -> "opencascade::handle< StepAP203_CcDesignDateAndTimeAssignment >":
    return _StepAP203.Handle_StepAP203_CcDesignDateAndTimeAssignment_Create()

def Handle_StepAP203_CcDesignDateAndTimeAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignDateAndTimeAssignment >":
    return _StepAP203.Handle_StepAP203_CcDesignDateAndTimeAssignment_DownCast(t)

def Handle_StepAP203_CcDesignDateAndTimeAssignment_IsNull(t: "opencascade::handle< StepAP203_CcDesignDateAndTimeAssignment > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignDateAndTimeAssignment_IsNull(t)

def Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_Create() -> "opencascade::handle< StepAP203_CcDesignPersonAndOrganizationAssignment >":
    return _StepAP203.Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_Create()

def Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignPersonAndOrganizationAssignment >":
    return _StepAP203.Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_DownCast(t)

def Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_IsNull(t: "opencascade::handle< StepAP203_CcDesignPersonAndOrganizationAssignment > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_IsNull(t)

def Handle_StepAP203_CcDesignSecurityClassification_Create() -> "opencascade::handle< StepAP203_CcDesignSecurityClassification >":
    return _StepAP203.Handle_StepAP203_CcDesignSecurityClassification_Create()

def Handle_StepAP203_CcDesignSecurityClassification_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignSecurityClassification >":
    return _StepAP203.Handle_StepAP203_CcDesignSecurityClassification_DownCast(t)

def Handle_StepAP203_CcDesignSecurityClassification_IsNull(t: "opencascade::handle< StepAP203_CcDesignSecurityClassification > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignSecurityClassification_IsNull(t)

def Handle_StepAP203_CcDesignSpecificationReference_Create() -> "opencascade::handle< StepAP203_CcDesignSpecificationReference >":
    return _StepAP203.Handle_StepAP203_CcDesignSpecificationReference_Create()

def Handle_StepAP203_CcDesignSpecificationReference_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_CcDesignSpecificationReference >":
    return _StepAP203.Handle_StepAP203_CcDesignSpecificationReference_DownCast(t)

def Handle_StepAP203_CcDesignSpecificationReference_IsNull(t: "opencascade::handle< StepAP203_CcDesignSpecificationReference > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_CcDesignSpecificationReference_IsNull(t)

def Handle_StepAP203_Change_Create() -> "opencascade::handle< StepAP203_Change >":
    return _StepAP203.Handle_StepAP203_Change_Create()

def Handle_StepAP203_Change_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_Change >":
    return _StepAP203.Handle_StepAP203_Change_DownCast(t)

def Handle_StepAP203_Change_IsNull(t: "opencascade::handle< StepAP203_Change > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_Change_IsNull(t)

def Handle_StepAP203_ChangeRequest_Create() -> "opencascade::handle< StepAP203_ChangeRequest >":
    return _StepAP203.Handle_StepAP203_ChangeRequest_Create()

def Handle_StepAP203_ChangeRequest_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_ChangeRequest >":
    return _StepAP203.Handle_StepAP203_ChangeRequest_DownCast(t)

def Handle_StepAP203_ChangeRequest_IsNull(t: "opencascade::handle< StepAP203_ChangeRequest > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_ChangeRequest_IsNull(t)

def Handle_StepAP203_StartRequest_Create() -> "opencascade::handle< StepAP203_StartRequest >":
    return _StepAP203.Handle_StepAP203_StartRequest_Create()

def Handle_StepAP203_StartRequest_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_StartRequest >":
    return _StepAP203.Handle_StepAP203_StartRequest_DownCast(t)

def Handle_StepAP203_StartRequest_IsNull(t: "opencascade::handle< StepAP203_StartRequest > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_StartRequest_IsNull(t)

def Handle_StepAP203_StartWork_Create() -> "opencascade::handle< StepAP203_StartWork >":
    return _StepAP203.Handle_StepAP203_StartWork_Create()

def Handle_StepAP203_StartWork_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_StartWork >":
    return _StepAP203.Handle_StepAP203_StartWork_DownCast(t)

def Handle_StepAP203_StartWork_IsNull(t: "opencascade::handle< StepAP203_StartWork > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_StartWork_IsNull(t)

def Handle_StepAP203_HArray1OfSpecifiedItem_Create() -> "opencascade::handle< StepAP203_HArray1OfSpecifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfSpecifiedItem_Create()

def Handle_StepAP203_HArray1OfSpecifiedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfSpecifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfSpecifiedItem_DownCast(t)

def Handle_StepAP203_HArray1OfSpecifiedItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfSpecifiedItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfSpecifiedItem_IsNull(t)

def Handle_StepAP203_HArray1OfPersonOrganizationItem_Create() -> "opencascade::handle< StepAP203_HArray1OfPersonOrganizationItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfPersonOrganizationItem_Create()

def Handle_StepAP203_HArray1OfPersonOrganizationItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfPersonOrganizationItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfPersonOrganizationItem_DownCast(t)

def Handle_StepAP203_HArray1OfPersonOrganizationItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfPersonOrganizationItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfPersonOrganizationItem_IsNull(t)

def Handle_StepAP203_HArray1OfChangeRequestItem_Create() -> "opencascade::handle< StepAP203_HArray1OfChangeRequestItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfChangeRequestItem_Create()

def Handle_StepAP203_HArray1OfChangeRequestItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfChangeRequestItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfChangeRequestItem_DownCast(t)

def Handle_StepAP203_HArray1OfChangeRequestItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfChangeRequestItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfChangeRequestItem_IsNull(t)

def Handle_StepAP203_HArray1OfContractedItem_Create() -> "opencascade::handle< StepAP203_HArray1OfContractedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfContractedItem_Create()

def Handle_StepAP203_HArray1OfContractedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfContractedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfContractedItem_DownCast(t)

def Handle_StepAP203_HArray1OfContractedItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfContractedItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfContractedItem_IsNull(t)

def Handle_StepAP203_HArray1OfCertifiedItem_Create() -> "opencascade::handle< StepAP203_HArray1OfCertifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfCertifiedItem_Create()

def Handle_StepAP203_HArray1OfCertifiedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfCertifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfCertifiedItem_DownCast(t)

def Handle_StepAP203_HArray1OfCertifiedItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfCertifiedItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfCertifiedItem_IsNull(t)

def Handle_StepAP203_HArray1OfStartRequestItem_Create() -> "opencascade::handle< StepAP203_HArray1OfStartRequestItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfStartRequestItem_Create()

def Handle_StepAP203_HArray1OfStartRequestItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfStartRequestItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfStartRequestItem_DownCast(t)

def Handle_StepAP203_HArray1OfStartRequestItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfStartRequestItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfStartRequestItem_IsNull(t)

def Handle_StepAP203_HArray1OfDateTimeItem_Create() -> "opencascade::handle< StepAP203_HArray1OfDateTimeItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfDateTimeItem_Create()

def Handle_StepAP203_HArray1OfDateTimeItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfDateTimeItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfDateTimeItem_DownCast(t)

def Handle_StepAP203_HArray1OfDateTimeItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfDateTimeItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfDateTimeItem_IsNull(t)

def Handle_StepAP203_HArray1OfApprovedItem_Create() -> "opencascade::handle< StepAP203_HArray1OfApprovedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfApprovedItem_Create()

def Handle_StepAP203_HArray1OfApprovedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfApprovedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfApprovedItem_DownCast(t)

def Handle_StepAP203_HArray1OfApprovedItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfApprovedItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfApprovedItem_IsNull(t)

def Handle_StepAP203_HArray1OfWorkItem_Create() -> "opencascade::handle< StepAP203_HArray1OfWorkItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfWorkItem_Create()

def Handle_StepAP203_HArray1OfWorkItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfWorkItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfWorkItem_DownCast(t)

def Handle_StepAP203_HArray1OfWorkItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfWorkItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfWorkItem_IsNull(t)

def Handle_StepAP203_HArray1OfClassifiedItem_Create() -> "opencascade::handle< StepAP203_HArray1OfClassifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfClassifiedItem_Create()

def Handle_StepAP203_HArray1OfClassifiedItem_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< StepAP203_HArray1OfClassifiedItem >":
    return _StepAP203.Handle_StepAP203_HArray1OfClassifiedItem_DownCast(t)

def Handle_StepAP203_HArray1OfClassifiedItem_IsNull(t: "opencascade::handle< StepAP203_HArray1OfClassifiedItem > const &") -> "bool":
    return _StepAP203.Handle_StepAP203_HArray1OfClassifiedItem_IsNull(t)
class StepAP203_Array1OfApprovedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_ApprovedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfApprovedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_ApprovedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfApprovedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_ApprovedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfApprovedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_ApprovedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfApprovedItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfApprovedItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfApprovedItem(*args))

    def Init(self, theValue: "StepAP203_ApprovedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfApprovedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfApprovedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfApprovedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfApprovedItem") -> "NCollection_Array1< StepAP203_ApprovedItem > &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfApprovedItem") -> "NCollection_Array1< StepAP203_ApprovedItem > &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_ApprovedItem > &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Set(self, *args)

    def First(self) -> "StepAP203_ApprovedItem const &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_First(self)

    def ChangeFirst(self) -> "StepAP203_ApprovedItem &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_ApprovedItem const &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Last(self)

    def ChangeLast(self) -> "StepAP203_ApprovedItem &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_ApprovedItem const &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_ApprovedItem &":
        return _StepAP203.StepAP203_Array1OfApprovedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_ApprovedItem &":
        return _StepAP203.StepAP203_Array1OfApprovedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_ApprovedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfApprovedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfApprovedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfApprovedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfApprovedItem in _StepAP203:
_StepAP203.StepAP203_Array1OfApprovedItem_swigregister(StepAP203_Array1OfApprovedItem)

class StepAP203_Array1OfCertifiedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_CertifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_CertifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_CertifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_CertifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfCertifiedItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfCertifiedItem(*args))

    def Init(self, theValue: "StepAP203_CertifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfCertifiedItem") -> "NCollection_Array1< StepAP203_CertifiedItem > &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfCertifiedItem") -> "NCollection_Array1< StepAP203_CertifiedItem > &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_CertifiedItem > &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Set(self, *args)

    def First(self) -> "StepAP203_CertifiedItem const &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_First(self)

    def ChangeFirst(self) -> "StepAP203_CertifiedItem &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_CertifiedItem const &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Last(self)

    def ChangeLast(self) -> "StepAP203_CertifiedItem &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_CertifiedItem const &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_CertifiedItem &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_CertifiedItem &":
        return _StepAP203.StepAP203_Array1OfCertifiedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_CertifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfCertifiedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfCertifiedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfCertifiedItem in _StepAP203:
_StepAP203.StepAP203_Array1OfCertifiedItem_swigregister(StepAP203_Array1OfCertifiedItem)

class StepAP203_Array1OfChangeRequestItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_ChangeRequestItem >::iterator":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_ChangeRequestItem >::iterator":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_ChangeRequestItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_ChangeRequestItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfChangeRequestItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfChangeRequestItem(*args))

    def Init(self, theValue: "StepAP203_ChangeRequestItem") -> "void":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfChangeRequestItem") -> "NCollection_Array1< StepAP203_ChangeRequestItem > &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfChangeRequestItem") -> "NCollection_Array1< StepAP203_ChangeRequestItem > &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_ChangeRequestItem > &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Set(self, *args)

    def First(self) -> "StepAP203_ChangeRequestItem const &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_First(self)

    def ChangeFirst(self) -> "StepAP203_ChangeRequestItem &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_ChangeRequestItem const &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Last(self)

    def ChangeLast(self) -> "StepAP203_ChangeRequestItem &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_ChangeRequestItem const &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_ChangeRequestItem &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_ChangeRequestItem &":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_ChangeRequestItem") -> "void":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfChangeRequestItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfChangeRequestItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfChangeRequestItem in _StepAP203:
_StepAP203.StepAP203_Array1OfChangeRequestItem_swigregister(StepAP203_Array1OfChangeRequestItem)

class StepAP203_Array1OfClassifiedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_ClassifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_ClassifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_ClassifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_ClassifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfClassifiedItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfClassifiedItem(*args))

    def Init(self, theValue: "StepAP203_ClassifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfClassifiedItem") -> "NCollection_Array1< StepAP203_ClassifiedItem > &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfClassifiedItem") -> "NCollection_Array1< StepAP203_ClassifiedItem > &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_ClassifiedItem > &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Set(self, *args)

    def First(self) -> "StepAP203_ClassifiedItem const &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_First(self)

    def ChangeFirst(self) -> "StepAP203_ClassifiedItem &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_ClassifiedItem const &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Last(self)

    def ChangeLast(self) -> "StepAP203_ClassifiedItem &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_ClassifiedItem const &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_ClassifiedItem &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_ClassifiedItem &":
        return _StepAP203.StepAP203_Array1OfClassifiedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_ClassifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfClassifiedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfClassifiedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfClassifiedItem in _StepAP203:
_StepAP203.StepAP203_Array1OfClassifiedItem_swigregister(StepAP203_Array1OfClassifiedItem)

class StepAP203_Array1OfContractedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_ContractedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfContractedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_ContractedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfContractedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_ContractedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfContractedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_ContractedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfContractedItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfContractedItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfContractedItem(*args))

    def Init(self, theValue: "StepAP203_ContractedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfContractedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfContractedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfContractedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfContractedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfContractedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfContractedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfContractedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfContractedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfContractedItem") -> "NCollection_Array1< StepAP203_ContractedItem > &":
        return _StepAP203.StepAP203_Array1OfContractedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfContractedItem") -> "NCollection_Array1< StepAP203_ContractedItem > &":
        return _StepAP203.StepAP203_Array1OfContractedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_ContractedItem > &":
        return _StepAP203.StepAP203_Array1OfContractedItem_Set(self, *args)

    def First(self) -> "StepAP203_ContractedItem const &":
        return _StepAP203.StepAP203_Array1OfContractedItem_First(self)

    def ChangeFirst(self) -> "StepAP203_ContractedItem &":
        return _StepAP203.StepAP203_Array1OfContractedItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_ContractedItem const &":
        return _StepAP203.StepAP203_Array1OfContractedItem_Last(self)

    def ChangeLast(self) -> "StepAP203_ContractedItem &":
        return _StepAP203.StepAP203_Array1OfContractedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_ContractedItem const &":
        return _StepAP203.StepAP203_Array1OfContractedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_ContractedItem &":
        return _StepAP203.StepAP203_Array1OfContractedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_ContractedItem &":
        return _StepAP203.StepAP203_Array1OfContractedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_ContractedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfContractedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfContractedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfContractedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfContractedItem in _StepAP203:
_StepAP203.StepAP203_Array1OfContractedItem_swigregister(StepAP203_Array1OfContractedItem)

class StepAP203_Array1OfDateTimeItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_DateTimeItem >::iterator":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_DateTimeItem >::iterator":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_DateTimeItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_DateTimeItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfDateTimeItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfDateTimeItem(*args))

    def Init(self, theValue: "StepAP203_DateTimeItem") -> "void":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfDateTimeItem") -> "NCollection_Array1< StepAP203_DateTimeItem > &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfDateTimeItem") -> "NCollection_Array1< StepAP203_DateTimeItem > &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_DateTimeItem > &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Set(self, *args)

    def First(self) -> "StepAP203_DateTimeItem const &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_First(self)

    def ChangeFirst(self) -> "StepAP203_DateTimeItem &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_DateTimeItem const &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Last(self)

    def ChangeLast(self) -> "StepAP203_DateTimeItem &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_DateTimeItem const &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_DateTimeItem &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_DateTimeItem &":
        return _StepAP203.StepAP203_Array1OfDateTimeItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_DateTimeItem") -> "void":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfDateTimeItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfDateTimeItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfDateTimeItem in _StepAP203:
_StepAP203.StepAP203_Array1OfDateTimeItem_swigregister(StepAP203_Array1OfDateTimeItem)

class StepAP203_Array1OfPersonOrganizationItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_PersonOrganizationItem >::iterator":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_PersonOrganizationItem >::iterator":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_PersonOrganizationItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_PersonOrganizationItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfPersonOrganizationItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfPersonOrganizationItem(*args))

    def Init(self, theValue: "StepAP203_PersonOrganizationItem") -> "void":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfPersonOrganizationItem") -> "NCollection_Array1< StepAP203_PersonOrganizationItem > &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfPersonOrganizationItem") -> "NCollection_Array1< StepAP203_PersonOrganizationItem > &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_PersonOrganizationItem > &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Set(self, *args)

    def First(self) -> "StepAP203_PersonOrganizationItem const &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_First(self)

    def ChangeFirst(self) -> "StepAP203_PersonOrganizationItem &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_PersonOrganizationItem const &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Last(self)

    def ChangeLast(self) -> "StepAP203_PersonOrganizationItem &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_PersonOrganizationItem const &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_PersonOrganizationItem &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_PersonOrganizationItem &":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_PersonOrganizationItem") -> "void":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfPersonOrganizationItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfPersonOrganizationItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfPersonOrganizationItem in _StepAP203:
_StepAP203.StepAP203_Array1OfPersonOrganizationItem_swigregister(StepAP203_Array1OfPersonOrganizationItem)

class StepAP203_Array1OfSpecifiedItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_SpecifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_SpecifiedItem >::iterator":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_SpecifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_SpecifiedItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfSpecifiedItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfSpecifiedItem(*args))

    def Init(self, theValue: "StepAP203_SpecifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfSpecifiedItem") -> "NCollection_Array1< StepAP203_SpecifiedItem > &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfSpecifiedItem") -> "NCollection_Array1< StepAP203_SpecifiedItem > &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_SpecifiedItem > &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Set(self, *args)

    def First(self) -> "StepAP203_SpecifiedItem const &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_First(self)

    def ChangeFirst(self) -> "StepAP203_SpecifiedItem &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_SpecifiedItem const &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Last(self)

    def ChangeLast(self) -> "StepAP203_SpecifiedItem &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_SpecifiedItem const &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_SpecifiedItem &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_SpecifiedItem &":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_SpecifiedItem") -> "void":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfSpecifiedItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfSpecifiedItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfSpecifiedItem in _StepAP203:
_StepAP203.StepAP203_Array1OfSpecifiedItem_swigregister(StepAP203_Array1OfSpecifiedItem)

class StepAP203_Array1OfStartRequestItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_StartRequestItem >::iterator":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_StartRequestItem >::iterator":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_StartRequestItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_StartRequestItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfStartRequestItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfStartRequestItem(*args))

    def Init(self, theValue: "StepAP203_StartRequestItem") -> "void":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfStartRequestItem") -> "NCollection_Array1< StepAP203_StartRequestItem > &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfStartRequestItem") -> "NCollection_Array1< StepAP203_StartRequestItem > &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_StartRequestItem > &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Set(self, *args)

    def First(self) -> "StepAP203_StartRequestItem const &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_First(self)

    def ChangeFirst(self) -> "StepAP203_StartRequestItem &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_StartRequestItem const &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Last(self)

    def ChangeLast(self) -> "StepAP203_StartRequestItem &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_StartRequestItem const &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_StartRequestItem &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_StartRequestItem &":
        return _StepAP203.StepAP203_Array1OfStartRequestItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_StartRequestItem") -> "void":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfStartRequestItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfStartRequestItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfStartRequestItem in _StepAP203:
_StepAP203.StepAP203_Array1OfStartRequestItem_swigregister(StepAP203_Array1OfStartRequestItem)

class StepAP203_Array1OfWorkItem(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def begin(self) -> "NCollection_Array1< StepAP203_WorkItem >::iterator":
        return _StepAP203.StepAP203_Array1OfWorkItem_begin(self)

    def end(self) -> "NCollection_Array1< StepAP203_WorkItem >::iterator":
        return _StepAP203.StepAP203_Array1OfWorkItem_end(self)

    def cbegin(self) -> "NCollection_Array1< StepAP203_WorkItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfWorkItem_cbegin(self)

    def cend(self) -> "NCollection_Array1< StepAP203_WorkItem >::const_iterator":
        return _StepAP203.StepAP203_Array1OfWorkItem_cend(self)

    def __init__(self, *args):
        _StepAP203.StepAP203_Array1OfWorkItem_swiginit(self, _StepAP203.new_StepAP203_Array1OfWorkItem(*args))

    def Init(self, theValue: "StepAP203_WorkItem") -> "void":
        return _StepAP203.StepAP203_Array1OfWorkItem_Init(self, theValue)

    def Size(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfWorkItem_Size(self)

    def Length(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfWorkItem_Length(self)

    def IsEmpty(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfWorkItem_IsEmpty(self)

    def Lower(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfWorkItem_Lower(self)

    def Upper(self) -> "Standard_Integer":
        return _StepAP203.StepAP203_Array1OfWorkItem_Upper(self)

    def IsDeletable(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfWorkItem_IsDeletable(self)

    def IsAllocated(self) -> "Standard_Boolean":
        return _StepAP203.StepAP203_Array1OfWorkItem_IsAllocated(self)

    def Assign(self, theOther: "StepAP203_Array1OfWorkItem") -> "NCollection_Array1< StepAP203_WorkItem > &":
        return _StepAP203.StepAP203_Array1OfWorkItem_Assign(self, theOther)

    def Move(self, theOther: "StepAP203_Array1OfWorkItem") -> "NCollection_Array1< StepAP203_WorkItem > &":
        return _StepAP203.StepAP203_Array1OfWorkItem_Move(self, theOther)

    def Set(self, *args) -> "NCollection_Array1< StepAP203_WorkItem > &":
        return _StepAP203.StepAP203_Array1OfWorkItem_Set(self, *args)

    def First(self) -> "StepAP203_WorkItem const &":
        return _StepAP203.StepAP203_Array1OfWorkItem_First(self)

    def ChangeFirst(self) -> "StepAP203_WorkItem &":
        return _StepAP203.StepAP203_Array1OfWorkItem_ChangeFirst(self)

    def Last(self) -> "StepAP203_WorkItem const &":
        return _StepAP203.StepAP203_Array1OfWorkItem_Last(self)

    def ChangeLast(self) -> "StepAP203_WorkItem &":
        return _StepAP203.StepAP203_Array1OfWorkItem_ChangeLast(self)

    def Value(self, theIndex: "Standard_Integer const") -> "StepAP203_WorkItem const &":
        return _StepAP203.StepAP203_Array1OfWorkItem_Value(self, theIndex)

    def ChangeValue(self, theIndex: "Standard_Integer const") -> "StepAP203_WorkItem &":
        return _StepAP203.StepAP203_Array1OfWorkItem_ChangeValue(self, theIndex)

    def __call__(self, *args) -> "StepAP203_WorkItem &":
        return _StepAP203.StepAP203_Array1OfWorkItem___call__(self, *args)

    def SetValue(self, theIndex: "Standard_Integer const", theItem: "StepAP203_WorkItem") -> "void":
        return _StepAP203.StepAP203_Array1OfWorkItem_SetValue(self, theIndex, theItem)

    def Resize(self, theLower: "Standard_Integer const", theUpper: "Standard_Integer const", theToCopyData: "Standard_Boolean const") -> "void":
        return _StepAP203.StepAP203_Array1OfWorkItem_Resize(self, theLower, theUpper, theToCopyData)
    __swig_destroy__ = _StepAP203.delete_StepAP203_Array1OfWorkItem

    def __getitem__(self, index):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            return self.Value(index + self.Lower())

    def __setitem__(self, index, value):
        if index + self.Lower() > self.Upper():
            raise IndexError("index out of range")
        else:
            self.SetValue(index + self.Lower(), value)

    def __len__(self):
        return self.Length()

    def __iter__(self):
        self.low = self.Lower()
        self.up = self.Upper()
        self.current = self.Lower() - 1
        return self

    def next(self):
        if self.current >= self.Upper():
            raise StopIteration
        else:
            self.current += 1
        return self.Value(self.current)

    __next__ = next


# Register StepAP203_Array1OfWorkItem in _StepAP203:
_StepAP203.StepAP203_Array1OfWorkItem_swigregister(StepAP203_Array1OfWorkItem)

class StepAP203_ApprovedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_ApprovedItem_swiginit(self, _StepAP203.new_StepAP203_ApprovedItem(*args))

    def Certification(self, *args) -> "opencascade::handle< StepBasic_Certification >":
        r"""
        Returns value as certification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Certification>

        """
        return _StepAP203.StepAP203_ApprovedItem_Certification(self, *args)

    def Change(self, *args) -> "opencascade::handle< StepAP203_Change >":
        r"""
        Returns value as change (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_Change>

        """
        return _StepAP203.StepAP203_ApprovedItem_Change(self, *args)

    def ChangeRequest(self, *args) -> "opencascade::handle< StepAP203_ChangeRequest >":
        r"""
        Returns value as changerequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_ChangeRequest>

        """
        return _StepAP203.StepAP203_ApprovedItem_ChangeRequest(self, *args)

    def ConfigurationEffectivity(self, *args) -> "opencascade::handle< StepRepr_ConfigurationEffectivity >":
        r"""
        Returns value as configurationeffectivity (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationEffectivity>

        """
        return _StepAP203.StepAP203_ApprovedItem_ConfigurationEffectivity(self, *args)

    def ConfigurationItem(self, *args) -> "opencascade::handle< StepRepr_ConfigurationItem >":
        r"""
        Returns value as configurationitem (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationItem>

        """
        return _StepAP203.StepAP203_ApprovedItem_ConfigurationItem(self, *args)

    def Contract(self, *args) -> "opencascade::handle< StepBasic_Contract >":
        r"""
        Returns value as contract (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Contract>

        """
        return _StepAP203.StepAP203_ApprovedItem_Contract(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP203.StepAP203_ApprovedItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_ApprovedItem_ProductDefinitionFormation(self, *args)

    def SecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        Returns value as securityclassification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepAP203.StepAP203_ApprovedItem_SecurityClassification(self, *args)

    def StartRequest(self, *args) -> "opencascade::handle< StepAP203_StartRequest >":
        r"""
        Returns value as startrequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartRequest>

        """
        return _StepAP203.StepAP203_ApprovedItem_StartRequest(self, *args)

    def StartWork(self, *args) -> "opencascade::handle< StepAP203_StartWork >":
        r"""
        Returns value as startwork (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartWork>

        """
        return _StepAP203.StepAP203_ApprovedItem_StartWork(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_ApprovedItem

# Register StepAP203_ApprovedItem in _StepAP203:
_StepAP203.StepAP203_ApprovedItem_swigregister(StepAP203_ApprovedItem)

class StepAP203_CcDesignApproval(OCC.Core.StepBasic.StepBasic_ApprovalAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignApproval_swiginit(self, _StepAP203.new_StepAP203_CcDesignApproval(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aApprovalAssignment_AssignedApproval: StepBasic_Approval
        aItems: StepAP203_HArray1OfApprovedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignApproval_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfApprovedItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfApprovedItem>

        """
        return _StepAP203.StepAP203_CcDesignApproval_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfApprovedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignApproval_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignApproval_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignApproval

# Register StepAP203_CcDesignApproval in _StepAP203:
_StepAP203.StepAP203_CcDesignApproval_swigregister(StepAP203_CcDesignApproval)

class StepAP203_CcDesignCertification(OCC.Core.StepBasic.StepBasic_CertificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignCertification_swiginit(self, _StepAP203.new_StepAP203_CcDesignCertification(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aCertificationAssignment_AssignedCertification: StepBasic_Certification
        aItems: StepAP203_HArray1OfCertifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignCertification_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfCertifiedItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfCertifiedItem>

        """
        return _StepAP203.StepAP203_CcDesignCertification_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfCertifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignCertification_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignCertification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignCertification

# Register StepAP203_CcDesignCertification in _StepAP203:
_StepAP203.StepAP203_CcDesignCertification_swigregister(StepAP203_CcDesignCertification)

class StepAP203_CcDesignContract(OCC.Core.StepBasic.StepBasic_ContractAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignContract_swiginit(self, _StepAP203.new_StepAP203_CcDesignContract(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aContractAssignment_AssignedContract: StepBasic_Contract
        aItems: StepAP203_HArray1OfContractedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignContract_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfContractedItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfContractedItem>

        """
        return _StepAP203.StepAP203_CcDesignContract_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfContractedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignContract_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignContract_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignContract

# Register StepAP203_CcDesignContract in _StepAP203:
_StepAP203.StepAP203_CcDesignContract_swigregister(StepAP203_CcDesignContract)

class StepAP203_CcDesignDateAndTimeAssignment(OCC.Core.StepBasic.StepBasic_DateAndTimeAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignDateAndTimeAssignment_swiginit(self, _StepAP203.new_StepAP203_CcDesignDateAndTimeAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDateAndTimeAssignment_AssignedDateAndTime: StepBasic_DateAndTime
        aDateAndTimeAssignment_Role: StepBasic_DateTimeRole
        aItems: StepAP203_HArray1OfDateTimeItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignDateAndTimeAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfDateTimeItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfDateTimeItem>

        """
        return _StepAP203.StepAP203_CcDesignDateAndTimeAssignment_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfDateTimeItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignDateAndTimeAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignDateAndTimeAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignDateAndTimeAssignment

# Register StepAP203_CcDesignDateAndTimeAssignment in _StepAP203:
_StepAP203.StepAP203_CcDesignDateAndTimeAssignment_swigregister(StepAP203_CcDesignDateAndTimeAssignment)

class StepAP203_CcDesignPersonAndOrganizationAssignment(OCC.Core.StepBasic.StepBasic_PersonAndOrganizationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignPersonAndOrganizationAssignment_swiginit(self, _StepAP203.new_StepAP203_CcDesignPersonAndOrganizationAssignment(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aPersonAndOrganizationAssignment_AssignedPersonAndOrganization: StepBasic_PersonAndOrganization
        aPersonAndOrganizationAssignment_Role: StepBasic_PersonAndOrganizationRole
        aItems: StepAP203_HArray1OfPersonOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignPersonAndOrganizationAssignment_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfPersonOrganizationItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfPersonOrganizationItem>

        """
        return _StepAP203.StepAP203_CcDesignPersonAndOrganizationAssignment_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfPersonOrganizationItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignPersonAndOrganizationAssignment_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignPersonAndOrganizationAssignment_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignPersonAndOrganizationAssignment

# Register StepAP203_CcDesignPersonAndOrganizationAssignment in _StepAP203:
_StepAP203.StepAP203_CcDesignPersonAndOrganizationAssignment_swigregister(StepAP203_CcDesignPersonAndOrganizationAssignment)

class StepAP203_CcDesignSecurityClassification(OCC.Core.StepBasic.StepBasic_SecurityClassificationAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignSecurityClassification_swiginit(self, _StepAP203.new_StepAP203_CcDesignSecurityClassification(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aSecurityClassificationAssignment_AssignedSecurityClassification: StepBasic_SecurityClassification
        aItems: StepAP203_HArray1OfClassifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignSecurityClassification_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfClassifiedItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfClassifiedItem>

        """
        return _StepAP203.StepAP203_CcDesignSecurityClassification_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfClassifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignSecurityClassification_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignSecurityClassification_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignSecurityClassification

# Register StepAP203_CcDesignSecurityClassification in _StepAP203:
_StepAP203.StepAP203_CcDesignSecurityClassification_swigregister(StepAP203_CcDesignSecurityClassification)

class StepAP203_CcDesignSpecificationReference(OCC.Core.StepBasic.StepBasic_DocumentReference):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CcDesignSpecificationReference_swiginit(self, _StepAP203.new_StepAP203_CcDesignSpecificationReference(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aDocumentReference_AssignedDocument: StepBasic_Document
        aDocumentReference_Source: TCollection_HAsciiString
        aItems: StepAP203_HArray1OfSpecifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignSpecificationReference_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfSpecifiedItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfSpecifiedItem>

        """
        return _StepAP203.StepAP203_CcDesignSpecificationReference_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfSpecifiedItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_CcDesignSpecificationReference_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_CcDesignSpecificationReference_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CcDesignSpecificationReference

# Register StepAP203_CcDesignSpecificationReference in _StepAP203:
_StepAP203.StepAP203_CcDesignSpecificationReference_swigregister(StepAP203_CcDesignSpecificationReference)

class StepAP203_CertifiedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_CertifiedItem_swiginit(self, _StepAP203.new_StepAP203_CertifiedItem(*args))

    def SuppliedPartRelationship(self, *args) -> "opencascade::handle< StepRepr_SuppliedPartRelationship >":
        r"""
        Returns value as suppliedpartrelationship (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_SuppliedPartRelationship>

        """
        return _StepAP203.StepAP203_CertifiedItem_SuppliedPartRelationship(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_CertifiedItem

# Register StepAP203_CertifiedItem in _StepAP203:
_StepAP203.StepAP203_CertifiedItem_swigregister(StepAP203_CertifiedItem)

class StepAP203_Change(OCC.Core.StepBasic.StepBasic_ActionAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_Change_swiginit(self, _StepAP203.new_StepAP203_Change(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aActionAssignment_AssignedAction: StepBasic_Action
        aItems: StepAP203_HArray1OfWorkItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_Change_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfWorkItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfWorkItem>

        """
        return _StepAP203.StepAP203_Change_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfWorkItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_Change_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_Change_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_Change

# Register StepAP203_Change in _StepAP203:
_StepAP203.StepAP203_Change_swigregister(StepAP203_Change)

class StepAP203_ChangeRequest(OCC.Core.StepBasic.StepBasic_ActionRequestAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_ChangeRequest_swiginit(self, _StepAP203.new_StepAP203_ChangeRequest(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aActionRequestAssignment_AssignedActionRequest: StepBasic_VersionedActionRequest
        aItems: StepAP203_HArray1OfChangeRequestItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_ChangeRequest_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfChangeRequestItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfChangeRequestItem>

        """
        return _StepAP203.StepAP203_ChangeRequest_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfChangeRequestItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_ChangeRequest_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_ChangeRequest_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_ChangeRequest

# Register StepAP203_ChangeRequest in _StepAP203:
_StepAP203.StepAP203_ChangeRequest_swigregister(StepAP203_ChangeRequest)

class StepAP203_ChangeRequestItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_ChangeRequestItem_swiginit(self, _StepAP203.new_StepAP203_ChangeRequestItem(*args))

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_ChangeRequestItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_ChangeRequestItem

# Register StepAP203_ChangeRequestItem in _StepAP203:
_StepAP203.StepAP203_ChangeRequestItem_swigregister(StepAP203_ChangeRequestItem)

class StepAP203_ClassifiedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_ClassifiedItem_swiginit(self, _StepAP203.new_StepAP203_ClassifiedItem(*args))

    def AssemblyComponentUsage(self, *args) -> "opencascade::handle< StepRepr_AssemblyComponentUsage >":
        r"""
        Returns value as assemblycomponentusage (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_AssemblyComponentUsage>

        """
        return _StepAP203.StepAP203_ClassifiedItem_AssemblyComponentUsage(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_ClassifiedItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_ClassifiedItem

# Register StepAP203_ClassifiedItem in _StepAP203:
_StepAP203.StepAP203_ClassifiedItem_swigregister(StepAP203_ClassifiedItem)

class StepAP203_ContractedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_ContractedItem_swiginit(self, _StepAP203.new_StepAP203_ContractedItem(*args))

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_ContractedItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_ContractedItem

# Register StepAP203_ContractedItem in _StepAP203:
_StepAP203.StepAP203_ContractedItem_swigregister(StepAP203_ContractedItem)

class StepAP203_DateTimeItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_DateTimeItem_swiginit(self, _StepAP203.new_StepAP203_DateTimeItem(*args))

    def ApprovalPersonOrganization(self, *args) -> "opencascade::handle< StepBasic_ApprovalPersonOrganization >":
        r"""
        Returns value as approvalpersonorganization (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ApprovalPersonOrganization>

        """
        return _StepAP203.StepAP203_DateTimeItem_ApprovalPersonOrganization(self, *args)

    def Certification(self, *args) -> "opencascade::handle< StepBasic_Certification >":
        r"""
        Returns value as certification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Certification>

        """
        return _StepAP203.StepAP203_DateTimeItem_Certification(self, *args)

    def Change(self, *args) -> "opencascade::handle< StepAP203_Change >":
        r"""
        Returns value as change (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_Change>

        """
        return _StepAP203.StepAP203_DateTimeItem_Change(self, *args)

    def ChangeRequest(self, *args) -> "opencascade::handle< StepAP203_ChangeRequest >":
        r"""
        Returns value as changerequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_ChangeRequest>

        """
        return _StepAP203.StepAP203_DateTimeItem_ChangeRequest(self, *args)

    def Contract(self, *args) -> "opencascade::handle< StepBasic_Contract >":
        r"""
        Returns value as contract (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Contract>

        """
        return _StepAP203.StepAP203_DateTimeItem_Contract(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP203.StepAP203_DateTimeItem_ProductDefinition(self, *args)

    def SecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        Returns value as securityclassification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepAP203.StepAP203_DateTimeItem_SecurityClassification(self, *args)

    def StartRequest(self, *args) -> "opencascade::handle< StepAP203_StartRequest >":
        r"""
        Returns value as startrequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartRequest>

        """
        return _StepAP203.StepAP203_DateTimeItem_StartRequest(self, *args)

    def StartWork(self, *args) -> "opencascade::handle< StepAP203_StartWork >":
        r"""
        Returns value as startwork (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartWork>

        """
        return _StepAP203.StepAP203_DateTimeItem_StartWork(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_DateTimeItem

# Register StepAP203_DateTimeItem in _StepAP203:
_StepAP203.StepAP203_DateTimeItem_swigregister(StepAP203_DateTimeItem)

class StepAP203_PersonOrganizationItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_PersonOrganizationItem_swiginit(self, _StepAP203.new_StepAP203_PersonOrganizationItem(*args))

    def Change(self, *args) -> "opencascade::handle< StepAP203_Change >":
        r"""
        Returns value as change (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_Change>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_Change(self, *args)

    def ChangeRequest(self, *args) -> "opencascade::handle< StepAP203_ChangeRequest >":
        r"""
        Returns value as changerequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_ChangeRequest>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_ChangeRequest(self, *args)

    def ConfigurationItem(self, *args) -> "opencascade::handle< StepRepr_ConfigurationItem >":
        r"""
        Returns value as configurationitem (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ConfigurationItem>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_ConfigurationItem(self, *args)

    def Contract(self, *args) -> "opencascade::handle< StepBasic_Contract >":
        r"""
        Returns value as contract (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Contract>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_Contract(self, *args)

    def Product(self, *args) -> "opencascade::handle< StepBasic_Product >":
        r"""
        Returns value as product (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_Product>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_Product(self, *args)

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_ProductDefinition(self, *args)

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_ProductDefinitionFormation(self, *args)

    def SecurityClassification(self, *args) -> "opencascade::handle< StepBasic_SecurityClassification >":
        r"""
        Returns value as securityclassification (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_SecurityClassification>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_SecurityClassification(self, *args)

    def StartRequest(self, *args) -> "opencascade::handle< StepAP203_StartRequest >":
        r"""
        Returns value as startrequest (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartRequest>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_StartRequest(self, *args)

    def StartWork(self, *args) -> "opencascade::handle< StepAP203_StartWork >":
        r"""
        Returns value as startwork (or null if another type).

        Returns
        -------
        opencascade::handle<StepAP203_StartWork>

        """
        return _StepAP203.StepAP203_PersonOrganizationItem_StartWork(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_PersonOrganizationItem

# Register StepAP203_PersonOrganizationItem in _StepAP203:
_StepAP203.StepAP203_PersonOrganizationItem_swigregister(StepAP203_PersonOrganizationItem)

class StepAP203_SpecifiedItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_SpecifiedItem_swiginit(self, _StepAP203.new_StepAP203_SpecifiedItem(*args))

    def ProductDefinition(self, *args) -> "opencascade::handle< StepBasic_ProductDefinition >":
        r"""
        Returns value as productdefinition (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinition>

        """
        return _StepAP203.StepAP203_SpecifiedItem_ProductDefinition(self, *args)

    def ShapeAspect(self, *args) -> "opencascade::handle< StepRepr_ShapeAspect >":
        r"""
        Returns value as shapeaspect (or null if another type).

        Returns
        -------
        opencascade::handle<StepRepr_ShapeAspect>

        """
        return _StepAP203.StepAP203_SpecifiedItem_ShapeAspect(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_SpecifiedItem

# Register StepAP203_SpecifiedItem in _StepAP203:
_StepAP203.StepAP203_SpecifiedItem_swigregister(StepAP203_SpecifiedItem)

class StepAP203_StartRequest(OCC.Core.StepBasic.StepBasic_ActionRequestAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_StartRequest_swiginit(self, _StepAP203.new_StepAP203_StartRequest(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aActionRequestAssignment_AssignedActionRequest: StepBasic_VersionedActionRequest
        aItems: StepAP203_HArray1OfStartRequestItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_StartRequest_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfStartRequestItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfStartRequestItem>

        """
        return _StepAP203.StepAP203_StartRequest_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfStartRequestItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_StartRequest_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_StartRequest_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_StartRequest

# Register StepAP203_StartRequest in _StepAP203:
_StepAP203.StepAP203_StartRequest_swigregister(StepAP203_StartRequest)

class StepAP203_StartRequestItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_StartRequestItem_swiginit(self, _StepAP203.new_StepAP203_StartRequestItem(*args))

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_StartRequestItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_StartRequestItem

# Register StepAP203_StartRequestItem in _StepAP203:
_StepAP203.StepAP203_StartRequestItem_swigregister(StepAP203_StartRequestItem)

class StepAP203_StartWork(OCC.Core.StepBasic.StepBasic_ActionAssignment):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_StartWork_swiginit(self, _StepAP203.new_StepAP203_StartWork(*args))

    def Init(self, *args) -> "void":
        r"""
        Initialize all fields (own and inherited).

        Parameters
        ----------
        aActionAssignment_AssignedAction: StepBasic_Action
        aItems: StepAP203_HArray1OfWorkItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_StartWork_Init(self, *args)

    def Items(self, *args) -> "opencascade::handle< StepAP203_HArray1OfWorkItem >":
        r"""
        Returns field items.

        Returns
        -------
        opencascade::handle<StepAP203_HArray1OfWorkItem>

        """
        return _StepAP203.StepAP203_StartWork_Items(self, *args)

    def SetItems(self, *args) -> "void":
        r"""
        Set field items.

        Parameters
        ----------
        Items: StepAP203_HArray1OfWorkItem

        Returns
        -------
        None

        """
        return _StepAP203.StepAP203_StartWork_SetItems(self, *args)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_StartWork_DownCast(t)


    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_StartWork

# Register StepAP203_StartWork in _StepAP203:
_StepAP203.StepAP203_StartWork_swigregister(StepAP203_StartWork)

class StepAP203_WorkItem(OCC.Core.StepData.StepData_SelectType):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        r"""
        Empty constructor.

        Returns
        -------
        None

        """
        _StepAP203.StepAP203_WorkItem_swiginit(self, _StepAP203.new_StepAP203_WorkItem(*args))

    def ProductDefinitionFormation(self, *args) -> "opencascade::handle< StepBasic_ProductDefinitionFormation >":
        r"""
        Returns value as productdefinitionformation (or null if another type).

        Returns
        -------
        opencascade::handle<StepBasic_ProductDefinitionFormation>

        """
        return _StepAP203.StepAP203_WorkItem_ProductDefinitionFormation(self, *args)

    __repr__ = _dumps_object

    __swig_destroy__ = _StepAP203.delete_StepAP203_WorkItem

# Register StepAP203_WorkItem in _StepAP203:
_StepAP203.StepAP203_WorkItem_swigregister(StepAP203_WorkItem)

class StepAP203_HArray1OfSpecifiedItem(StepAP203_Array1OfSpecifiedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfSpecifiedItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfSpecifiedItem(*args))

    def Array1(self) -> "StepAP203_Array1OfSpecifiedItem const &":
        return _StepAP203.StepAP203_HArray1OfSpecifiedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfSpecifiedItem &":
        return _StepAP203.StepAP203_HArray1OfSpecifiedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfSpecifiedItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfSpecifiedItem

# Register StepAP203_HArray1OfSpecifiedItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfSpecifiedItem_swigregister(StepAP203_HArray1OfSpecifiedItem)

class StepAP203_HArray1OfPersonOrganizationItem(StepAP203_Array1OfPersonOrganizationItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfPersonOrganizationItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfPersonOrganizationItem(*args))

    def Array1(self) -> "StepAP203_Array1OfPersonOrganizationItem const &":
        return _StepAP203.StepAP203_HArray1OfPersonOrganizationItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfPersonOrganizationItem &":
        return _StepAP203.StepAP203_HArray1OfPersonOrganizationItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfPersonOrganizationItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfPersonOrganizationItem

# Register StepAP203_HArray1OfPersonOrganizationItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfPersonOrganizationItem_swigregister(StepAP203_HArray1OfPersonOrganizationItem)

class StepAP203_HArray1OfChangeRequestItem(StepAP203_Array1OfChangeRequestItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfChangeRequestItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfChangeRequestItem(*args))

    def Array1(self) -> "StepAP203_Array1OfChangeRequestItem const &":
        return _StepAP203.StepAP203_HArray1OfChangeRequestItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfChangeRequestItem &":
        return _StepAP203.StepAP203_HArray1OfChangeRequestItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfChangeRequestItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfChangeRequestItem

# Register StepAP203_HArray1OfChangeRequestItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfChangeRequestItem_swigregister(StepAP203_HArray1OfChangeRequestItem)

class StepAP203_HArray1OfContractedItem(StepAP203_Array1OfContractedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfContractedItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfContractedItem(*args))

    def Array1(self) -> "StepAP203_Array1OfContractedItem const &":
        return _StepAP203.StepAP203_HArray1OfContractedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfContractedItem &":
        return _StepAP203.StepAP203_HArray1OfContractedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfContractedItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfContractedItem

# Register StepAP203_HArray1OfContractedItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfContractedItem_swigregister(StepAP203_HArray1OfContractedItem)

class StepAP203_HArray1OfCertifiedItem(StepAP203_Array1OfCertifiedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfCertifiedItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfCertifiedItem(*args))

    def Array1(self) -> "StepAP203_Array1OfCertifiedItem const &":
        return _StepAP203.StepAP203_HArray1OfCertifiedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfCertifiedItem &":
        return _StepAP203.StepAP203_HArray1OfCertifiedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfCertifiedItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfCertifiedItem

# Register StepAP203_HArray1OfCertifiedItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfCertifiedItem_swigregister(StepAP203_HArray1OfCertifiedItem)

class StepAP203_HArray1OfStartRequestItem(StepAP203_Array1OfStartRequestItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfStartRequestItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfStartRequestItem(*args))

    def Array1(self) -> "StepAP203_Array1OfStartRequestItem const &":
        return _StepAP203.StepAP203_HArray1OfStartRequestItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfStartRequestItem &":
        return _StepAP203.StepAP203_HArray1OfStartRequestItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfStartRequestItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfStartRequestItem

# Register StepAP203_HArray1OfStartRequestItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfStartRequestItem_swigregister(StepAP203_HArray1OfStartRequestItem)

class StepAP203_HArray1OfDateTimeItem(StepAP203_Array1OfDateTimeItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfDateTimeItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfDateTimeItem(*args))

    def Array1(self) -> "StepAP203_Array1OfDateTimeItem const &":
        return _StepAP203.StepAP203_HArray1OfDateTimeItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfDateTimeItem &":
        return _StepAP203.StepAP203_HArray1OfDateTimeItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfDateTimeItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfDateTimeItem

# Register StepAP203_HArray1OfDateTimeItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfDateTimeItem_swigregister(StepAP203_HArray1OfDateTimeItem)

class StepAP203_HArray1OfApprovedItem(StepAP203_Array1OfApprovedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfApprovedItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfApprovedItem(*args))

    def Array1(self) -> "StepAP203_Array1OfApprovedItem const &":
        return _StepAP203.StepAP203_HArray1OfApprovedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfApprovedItem &":
        return _StepAP203.StepAP203_HArray1OfApprovedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfApprovedItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfApprovedItem

# Register StepAP203_HArray1OfApprovedItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfApprovedItem_swigregister(StepAP203_HArray1OfApprovedItem)

class StepAP203_HArray1OfWorkItem(StepAP203_Array1OfWorkItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfWorkItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfWorkItem(*args))

    def Array1(self) -> "StepAP203_Array1OfWorkItem const &":
        return _StepAP203.StepAP203_HArray1OfWorkItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfWorkItem &":
        return _StepAP203.StepAP203_HArray1OfWorkItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfWorkItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfWorkItem

# Register StepAP203_HArray1OfWorkItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfWorkItem_swigregister(StepAP203_HArray1OfWorkItem)

class StepAP203_HArray1OfClassifiedItem(StepAP203_Array1OfClassifiedItem, OCC.Core.Standard.Standard_Transient):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __init__(self, *args):
        _StepAP203.StepAP203_HArray1OfClassifiedItem_swiginit(self, _StepAP203.new_StepAP203_HArray1OfClassifiedItem(*args))

    def Array1(self) -> "StepAP203_Array1OfClassifiedItem const &":
        return _StepAP203.StepAP203_HArray1OfClassifiedItem_Array1(self)

    def ChangeArray1(self) -> "StepAP203_Array1OfClassifiedItem &":
        return _StepAP203.StepAP203_HArray1OfClassifiedItem_ChangeArray1(self)


    @staticmethod
    def DownCast(t):
      return Handle_StepAP203_HArray1OfClassifiedItem_DownCast(t)

    __swig_destroy__ = _StepAP203.delete_StepAP203_HArray1OfClassifiedItem

# Register StepAP203_HArray1OfClassifiedItem in _StepAP203:
_StepAP203.StepAP203_HArray1OfClassifiedItem_swigregister(StepAP203_HArray1OfClassifiedItem)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *


class IntAna2d_AnaIntersection:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, L1: gp_Lin2d, L2: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, C1: gp_Circ2d, C2: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, L: gp_Lin2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def __init__(self, C: gp_Circ2d, Co: IntAna2d_Conic) -> None: ...
	@overload
	def __init__(self, E: gp_Elips2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def __init__(self, P: gp_Parab2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def __init__(self, H: gp_Hypr2d, C: IntAna2d_Conic) -> None: ...
	def IdenticalElements(self) -> bool: ...
	def IsDone(self) -> bool: ...
	def IsEmpty(self) -> bool: ...
	def NbPoints(self) -> int: ...
	def ParallelElements(self) -> bool: ...
	@overload
	def Perform(self, L1: gp_Lin2d, L2: gp_Lin2d) -> None: ...
	@overload
	def Perform(self, C1: gp_Circ2d, C2: gp_Circ2d) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, C: gp_Circ2d) -> None: ...
	@overload
	def Perform(self, L: gp_Lin2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def Perform(self, C: gp_Circ2d, Co: IntAna2d_Conic) -> None: ...
	@overload
	def Perform(self, E: gp_Elips2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def Perform(self, P: gp_Parab2d, C: IntAna2d_Conic) -> None: ...
	@overload
	def Perform(self, H: gp_Hypr2d, C: IntAna2d_Conic) -> None: ...
	def Point(self, N: int) -> IntAna2d_IntPoint: ...

class IntAna2d_Conic:
	@overload
	def __init__(self, C: gp_Circ2d) -> None: ...
	@overload
	def __init__(self, C: gp_Lin2d) -> None: ...
	@overload
	def __init__(self, C: gp_Parab2d) -> None: ...
	@overload
	def __init__(self, C: gp_Hypr2d) -> None: ...
	@overload
	def __init__(self, C: gp_Elips2d) -> None: ...
	def Coefficients(self) -> Tuple[float, float, float, float, float, float]: ...
	def Grad(self, X: float, Y: float) -> gp_XY: ...
	def NewCoefficients(self, Axis: gp_Ax2d) -> Tuple[float, float, float, float, float, float]: ...
	def ValAndGrad(self, X: float, Y: float, Grd: gp_XY) -> float: ...
	def Value(self, X: float, Y: float) -> float: ...

class IntAna2d_IntPoint:
	@overload
	def __init__(self, X: float, Y: float, U1: float, U2: float) -> None: ...
	@overload
	def __init__(self, X: float, Y: float, U1: float) -> None: ...
	@overload
	def __init__(self) -> None: ...
	def ParamOnFirst(self) -> float: ...
	def ParamOnSecond(self) -> float: ...
	def SecondIsImplicit(self) -> bool: ...
	@overload
	def SetValue(self, X: float, Y: float, U1: float, U2: float) -> None: ...
	@overload
	def SetValue(self, X: float, Y: float, U1: float) -> None: ...
	def Value(self) -> gp_Pnt2d: ...

# harray1 classes
# harray2 classes
# hsequence classes

